.. figure:: Pharmpy_logo.svg
   :class: only-light no-scaled-link
   :width: 400
   :align: center

.. figure:: Pharmpy_logo_dark.svg
   :class: only-dark no-scaled-link
   :width: 400
   :align: center

==================
Welcome to Pharmpy
==================


Pharmpy is a library and a set of tools for pharmacometrics. It can be used as a regular Python package, in R using the
pharmr package or via its built-in command line interface. Current features include:

* General model abstraction for pharmacometric models
* Manipulation of models
* Extraction of model estimation results
* Manipulation of datasets
* Various calculations and evaluations
* Plugin system to support different model formats (NONMEM, nlmixr2, rxode2)
* Running models (NONMEM, nlmixr2, rxode2)
* Running higher level workflows or tools (NONMEM)
* Parsing and updating NONMEM models
* Model conversion to NONMEM, nlmixr2, and rxode2

We encourage your contribution to the Pharmpy project! You can report issues and post suggestions of features via
GitHub issues (to `Pharmpy <https://github.com/pharmpy/pharmpy/issues>`_ or to
`pharmr <https://github.com/pharmpy/pharmr/issues>`_). If you want to contribute with code you can find more information
under :ref:`contribute`.

Pharmpy is maintained by the Uppsala University Pharmacometrics group and is an open-source project.

.. toctree::
   :hidden:

   About us <contributors>
   getting_started
   user_guide
   api
   changelog
   contribute
   References and citation <citation>
   license
   developers
